Forking PyKOALA
===============

Working on a fork enables you to develop your own copy of PyKOALA, contributing your code back to the main repository through a "pull request."

How to fork
-----------
First, click “Fork this repository” on the main PyKOALA repository in github. You then have your own copy of PyKOALA in github.com/USERNAME/koala

.. figure:: ../_static/figures/fork_buttom.png

How to work on your fork
------------------------
Clone a copy of your fork onto a local machine:
::

    git clone git@github.com:USERNAME/koala

This gets a copy of the entire repository. Here replace USERNAME with your GitHub username.


How to update your fork from the main PyKOALA repo
--------------------------------------------------

Make a
